@@ -1,12 +1,12 @@
-/* 
- *	SYNOPSIS:	parseargs(argc,argv)
- *	FILE :		parseargs.c
+/*
+ *	SYNOPSIS:	ick_parseargs(argc,argv)
+ *	FILE :		ick_parseargs.c
  *	AUTHOR :	Steve Swales
  *	DATE:		October 7, 1990
  *	PURPOSE: 	Parse arguments for INTERCAL programs.
  *
 LICENSE TERMS
-    Copyright (C) 1996 Eric S. Raymond 
+    Copyright (C) 1996 Eric S. Raymond
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -24,29 +24,44 @@ LICENSE TERMS
  */
 #include <stdio.h>
 #include <stdlib.h>
-#include <unistd.h>
+#include <string.h>
+#include <setjmp.h>
+#include "config.h"
 #include "abcess.h"
-#include "lose.h"
+#include "ick_lose.h"
 
-int traditional = 0;
-int wimp_mode = 0;
+/*@-redef@*/ /* it's never the case that both are used at once */
+int ick_traditional = 0;
+/*@=redef@*/
+int ick_wimp_mode = 0;
+int ick_instapipe = 0; /* AIS */
+int ick_printflow = 0; /* AIS */
+int ick_mystery = 0; /* AIS */
+
+unsigned long ick_mysteryc = 0; /* AIS */
 
 void
-parseargs(int argc, char **argv)
+ick_parseargs(int argc, char **argv)
 {
     register int i, j;
     static int helpflag = -1;
-    static char *flags[] = {
+    static const char *flags[] = {
 	"help",
 	"wimpmode",
-	"traditional"
+	"traditional",
+	"instapipe", /* AIS */
+	"printflow", /* AIS */
+	"mystery", /* AIS */
       };
     static int *bools[] = {
 	&helpflag,
-	&wimp_mode,
-	&traditional
+	&ick_wimp_mode,
+	&ick_traditional,
+	&ick_instapipe, /* AIS */
+	&ick_printflow, /* AIS */
+	&ick_mystery, /* AIS */
       };
-    static int nflags = (int)(sizeof(flags)/sizeof(flags[0]));
+    static const int nflags = (int)(sizeof(flags)/sizeof(flags[0]));
 
     for(i = 1;i < argc;i++) {
 	if(argv[i][0] != '+' && argv[i][0] != '-') {
@@ -68,7 +83,6 @@ parseargs(int argc, char **argv)
 	    fprintf(stderr,
 		    "Once you start messing with INTERCAL... \n");
 	    fprintf(stderr,"\t\tthere is no help for you!\n\n");
-	    sleep(3);
 	}
 	fprintf(stderr,"Current flags (and current state) are:\n");
 	for(i = 0;i < nflags;i++) {
@@ -80,11 +94,10 @@ parseargs(int argc, char **argv)
 	fprintf(stderr," but not always, and not all of them currently\n");
 	fprintf(stderr," do anything, but you can switch them on or off\n");
 	fprintf(stderr," if you like anyway. Isn't this helpful?\n\n");
-	fflush(stderr);
-	sleep(3);
-	lose(E778, 0, (char *)NULL);
+	(void) fflush(stderr);
+	ick_lose(IE990, 0, (const char *)NULL);
     }
-    if(wimp_mode) {
+    if(ick_wimp_mode) {
 	fprintf(stderr,"How sad... you have selected to run an INTERCAL\n");
 	fprintf(stderr,"program in WIMP MODE.\n\n");
 	fprintf(stderr,"This means that:\n");
@@ -96,6 +109,6 @@ parseargs(int argc, char **argv)
 	fprintf(stderr,"    you will have to settle for plain old number\n");
 	fprintf(stderr,"    representations like 1972063; and,\n");
 	fprintf(stderr," B) You are a WIMP!\n\n");
-	fflush(stderr);
+	(void) fflush(stderr);
     }
 }
